#include <libxml/parser.h>
#include <libxml/xpath.h>
#include <libxml/xpathInternals.h>
#include <libxml/xmlsave.h>
#include <libxml/HTMLparser.h>
#include <libxml/xmlschemastypes.h>
#include <libxml/xmlschemas.h>